**********************
Contributing to SFChat
**********************

Reporting issues
================
When reporting *bug* issues please use template:

* Problem
* Details
* Steps to reproduce
* Environment

For instance:

*Problem*: Chat was unexpectedly close

*Details*: In the middle of conversation messages were no delivered. After refreshing page the 500 Page was shown.

*Steps to reproduce*:

#. Create and join chat
#. After one and a half hour it freeze
#. Refresh page

*Environment*: Ubuntu 14.04 LTS, Chrome v44

Such details helps us to reproduce issue and fix them faster.

Contributing policy
===================
To contribute please read `Guide to Start Contributing <https://guides.github.com/activities/contributing-to-open-source/>`_.

Please make sure that your code follows `PEP 8 <https://www.python.org/dev/peps/pep-0008/>`_ and covered by unit tests.

If you want to help please check the `list of open issues <https://github.com/MySmile/sfchat/issues>`_.
